abacusai.api_class.project — AbacusAI documentation

# abacusai.api_class.project

## Classes

`FeatureMappingConfig` | Feature mapping configuration for a feature group type.
`ProjectFeatureGroupTypeMappingsConfig` | Project feature group type mappings.
`ConstraintConfig` | Constraint configuration.
`ProjectFeatureGroupConfig` | An abstract class for project feature group configuration.
`ConstraintProjectFeatureGroupConfig` | Constraint project feature group configuration.
`ReviewModeProjectFeatureGroupConfig` | Review mode project feature group configuration.
`_ProjectFeatureGroupConfigFactory` | Helper class that provides a standard way to create an ABC using

## Module Contents

class abacusai.api_class.project.FeatureMappingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Feature mapping configuration for a feature group type.

  Parameters:

    - feature_name (str) – The name of the feature in the feature group.

    - feature_mapping (str) – The desired feature mapping for the feature.

    - nested_feature_name (str) – The name of the nested feature in the feature group.

  feature_name: str
  feature_mapping: str
  nested_feature_name: str

class abacusai.api_class.project.ProjectFeatureGroupTypeMappingsConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Project feature group type mappings.

  Parameters:

    - feature_group_id (str) – The unique identifier for the feature group.

    - feature_group_type (str) – The feature group type.

    - feature_mappings (List[FeatureMappingConfig]) – The feature mappings for the feature group.

  feature_group_id: str
  feature_group_type: str
  feature_mappings: List[FeatureMappingConfig]
  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict)

class abacusai.api_class.project.ConstraintConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Constraint configuration.

  Parameters:

    - constant (float) – The constant value for the constraint.

    - operator (str) – The operator for the constraint. Could be ‘EQ’, ‘LE’, ‘GE’

    - enforcement (str) – The enforcement for the constraint. Could be ‘HARD’ or ‘SOFT’. Default is ‘HARD’

    - code (str) – The code for the constraint.

    - penalty (float) – The penalty for violating the constraint.

  constant: float
  operator: str
  enforcement: str | None
  code: str | None
  penalty: float | None

class abacusai.api_class.project.ProjectFeatureGroupConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  An abstract class for project feature group configuration.

  type: abacusai.api_class.enums.ProjectConfigType
  classmethod _get_builder()

class abacusai.api_class.project.ConstraintProjectFeatureGroupConfig

  Bases: `ProjectFeatureGroupConfig`

  Constraint project feature group configuration.

  Parameters:

    constraints (List[ConstraintConfig]) – The constraint for the feature group. Should be a list of one ConstraintConfig.

  constraints: List[ConstraintConfig]
  __post_init__()

class abacusai.api_class.project.ReviewModeProjectFeatureGroupConfig

  Bases: `ProjectFeatureGroupConfig`

  Review mode project feature group configuration.

  Parameters:

    is_review_mode (bool) – The review mode for the feature group.

  is_review_mode: bool
  __post_init__()

class abacusai.api_class.project._ProjectFeatureGroupConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'type'
  config_class_map